Module cpu

Module cpu 

CpuBackend — the always-available backend, using rayon to parallelize over batch items (and, for single values, over channels above a threshold).

Structs

CpuBackend
CPU backend backed by a dedicated rayon thread pool.